==> apimodule-1.0.5.tar.gz: lib/msimpersaa/response/spk_response.dart <==
class SpkResponse {
  bool con;
  String msg;
  List<SpkResults> results;

  SpkResponse({this.con, this.msg, this.results});

  SpkResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <SpkResults>[];
      json['results'].forEach((v) {
        results.add(SpkResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class SpkResults {
  int id;
  String nomorSpk;
  String nomorStr;
  String tanggalTerbit;
  String tanggalBerlaku;
  String documen;
  String pathFile;

  SpkResults(
      {this.id,
      this.nomorSpk,
      this.nomorStr,
      this.tanggalTerbit,
      this.tanggalBerlaku,
      this.documen,
      this.pathFile});

  SpkResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nomorSpk = json['nomor_spk'];
    nomorStr = json['nomor_str'];
    tanggalTerbit = json['tanggal_terbit'];
    tanggalBerlaku = json['tanggal_berlaku'];
    documen = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nomor_spk'] = this.nomorSpk;
    data['nomor_str'] = this.nomorStr;
    data['tanggal_terbit'] = this.tanggalTerbit;
    data['tanggal_berlaku'] = this.tanggalBerlaku;
    data['dokumen'] = this.documen;
    data['path_file'] = this.pathFile;
    return data;
  }
}

==> apimodule-1.1.5.tar.gz: lib/msimpersaa/response/spk_response.dart <==
class SpkResponse {
  bool con;
  String msg;
  List<SpkResults> results;

  SpkResponse({this.con, this.msg, this.results});

  SpkResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <SpkResults>[];
      json['results'].forEach((v) {
        results.add(SpkResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class SpkResults {
  int id;
  String nomorSpk;
  String nomorStr;
  String tanggalTerbit;
  String tanggalBerlaku;
  String document;
  String pathFile;

  SpkResults(
      {this.id,
      this.nomorSpk,
      this.nomorStr,
      this.tanggalTerbit,
      this.tanggalBerlaku,
      this.document,
      this.pathFile});

  SpkResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nomorSpk = json['nomor_spk'];
    nomorStr = json['nomor_str'];
    tanggalTerbit = json['tanggal_terbit'];
    tanggalBerlaku = json['tanggal_berlaku'];
    document = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nomor_spk'] = this.nomorSpk;
    data['nomor_str'] = this.nomorStr;
    data['tanggal_terbit'] = this.tanggalTerbit;
    data['tanggal_berlaku'] = this.tanggalBerlaku;
    data['dokumen'] = this.document;
    data['path_file'] = this.pathFile;
    return data;
  }
}
